@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -40,9 +41,7 @@
 #include <com/sun/star/drawing/XMasterPagesSupplier.hpp>
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/awt/FontDescriptor.hpp>
-#ifndef _COM_SUN_STAR_AWT_XFONTWEIGHT_HPP_
 #include <com/sun/star/awt/FontWeight.hpp>
-#endif
 #include <rtl/ustrbuf.hxx>
 
 using namespace ::rtl;
@@ -958,3 +957,5 @@ void OptimizerDialog::DeactivatePage( sal_Int16 nStep )
     while( aBeg != aEnd )
         setVisible( *aBeg++, sal_False );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
